@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool/child.c,v 1.5 2005/11/09 14:12:21 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool/child.c,v 1.6 2006/01/03 03:33:10 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -80,6 +80,8 @@ void do_child(int unix_fd, int inet_fd)
 	int child_idle_sec;
 	struct timeval timeout;
 	static int connected;
+	int connections_count = 0;	/* used if child_max_connections > 0 */
+
 
 	pool_debug("I am %d", getpid());
 
@@ -136,7 +138,7 @@ void do_child(int unix_fd, int inet_fd)
 		/* perform accept() */
 		frontend = do_accept(unix_fd, inet_fd, &timeout);
 
-		if (frontend == NULL)
+		if (frontend == NULL)	/* connection request from frontend timed out */
 		{
 			/* check select() timeout */
 			if (connected && pool_config.child_life_time > 0 &&
@@ -354,6 +356,18 @@ void do_child(int unix_fd, int inet_fd)
 		timeout.tv_sec = pool_config.child_life_time;
 		timeout.tv_usec = 0;
 
+		/* increment queries counter if necessary */
+		if ( pool_config.child_max_connections > 0 )
+			connections_count++;
+
+		/* check if maximum connections count for this child reached */
+		if ( ( pool_config.child_max_connections > 0 ) &&
+			( connections_count >= pool_config.child_max_connections ) )
+		{
+			pool_log("child exiting, %d connections reached", pool_config.child_max_connections);
+			send_frontend_exits();
+			exit(2);
+		}
 	}
 	exit(0);
 }
