@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool/pool_process_query.c,v 1.8 2005/11/09 14:12:21 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool/pool_process_query.c,v 1.10 2006/01/05 13:08:44 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -1946,8 +1946,8 @@ static void process_reporting(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *b
 	status[i].desc = "insert lock";
 	i++;
 
-	status[i].name = "ignore_leading_whitespace";
-	snprintf(status[i].value, MAXVALLEN, "%d", pool_config.insert_lock);
+	status[i].name = "ignore_leading_white_space";
+	snprintf(status[i].value, MAXVALLEN, "%d", pool_config.ignore_leading_white_space);
 	status[i].desc = "ignore leading white spaces";
 	i++;
 
